@@ -25,6 +25,8 @@
 #include <config.h>
 #endif
 
+#define MSG_SETUP_PROJ_SEARCH_PATH 1
+
 #include "aven.h"
 #include "log.h"
 #include "gla.h"
@@ -461,7 +463,7 @@ aven_v_report(int severity, const char *fnm, int line, int en, va_list ap)
 	m += wxT(": ");
     }
 
-    if (severity == 0) {
+    if (severity == DIAG_WARN) {
 	m += wmsg(/*warning*/4);
 	m += wxT(": ");
     }
